# Information Theory and Relativity: established connections for spacetime emergence

The intersection of information theory and relativity represents one of physics' most profound theoretical developments, with established frameworks demonstrating that spacetime geometry emerges from information-theoretic principles. The 511 keV electron rest mass scale appears as a fundamental boundary where classical electromagnetic descriptions fail and quantum field theory becomes essential, while the Lorentz factor directly controls information accessibility between reference frames.

## Information-theoretic formulations of relativity

Modern physics has developed several rigorous frameworks connecting information theory to both special and general relativity. The most significant breakthrough came from **Jacobson's thermodynamic derivation** (Physical Review Letters, 1995), which showed Einstein's field equations emerge directly from the thermodynamic relation δQ = TdS applied to local Rindler horizons. This approach uses the Unruh temperature T = ℏa/2πck_B for accelerated observers and identifies entropy with horizon area: S = A/4G_ℏ.

**Erik Verlinde's entropic gravity** (JHEP, 2011) extended this paradigm by proposing gravity emerges as an entropic force from information changes on holographic screens. His framework uses F = T∇S with the same temperature relation, deriving Newton's laws from pure information-theoretic principles. While controversial, this approach has over 1000 citations and sparked extensive theoretical development.

The **holographic principle** provides perhaps the most concrete information-relativity connection. The Ryu-Takayanagi formula (PRL, 2006) shows entanglement entropy SA = Area(γA)/4G_ℏ, where γA is the minimal bulk surface. This demonstrates spacetime geometry literally encodes quantum entanglement structure, with AdS/CFT correspondence providing explicit realizations where (d+1)-dimensional gravity equals d-dimensional conformal field theory.

## Electron rest mass as electromagnetic confinement scale

The 511 keV electron rest mass represents a fundamental scale in electromagnetic theory where classical and quantum descriptions meet. The **classical electron radius** re = e²/(4πε₀mec²) ≈ 2.82 × 10⁻¹⁵ m marks where electrostatic self-energy equals rest mass energy. At this scale, classical electromagnetic calculations diverge, requiring quantum field theory renormalization.

Historical work by **Abraham, Lorentz, and Poincaré** (1902-1906) attempted purely electromagnetic mass models. Poincaré introduced non-electromagnetic "stresses" contributing ~1/3 of electron energy to prevent electromagnetic instability. Modern QED calculations (Hönemann et al., 2018; Duhr et al., 2024) provide precise self-energy corrections, confirming the 511 keV scale as the boundary where perturbative expansions require careful treatment.

**A.O. Barut's self-field QED** (Physical Review A) demonstrates radiative effects can emerge from matter self-interaction without field quantization, treating 511 keV as the characteristic scale for electromagnetic interactions. Wave packet studies show electron localization becomes impossible below this scale - packets spread in ~10⁻¹⁶ seconds, demonstrating fundamental limits on electromagnetic confinement.

## The 511 keV scale in atomic physics

While extensively studied in positronium physics and astrophysical contexts, the 511 keV scale's role as a fundamental atomic physics boundary appears underexplored in literature. The scale primarily appears through:

**Positronium formation** occurs above 6.8 eV threshold, with subsequent decay producing characteristic 511 keV photons. The galactic 511 keV emission line observed by INTEGRAL/SPI remains a major astrophysical puzzle, suggesting widespread positron annihilation processes.

**Relativistic atomic effects** become significant when binding energies approach the electron rest mass. For highly charged ions with Z > 70, K-shell binding energies can exceed 100 keV, making relativistic Dirac-Fock calculations essential. The 511 keV scale thus marks where non-relativistic atomic physics definitively fails.

The literature gap regarding 511 keV as a quantum-classical transition scale suggests opportunity for theoretical development. While the electron rest mass provides a natural atomic energy scale, explicit connections to correspondence principles remain unexplored.

## Lorentz factor and information exchange

The **Peres-Terno framework** (Reviews of Modern Physics, 2004) established that quantum information transforms non-covariantly under Lorentz boosts. The Lorentz factor γ directly controls information accessibility - different inertial observers extract different amounts of information from identical quantum states. This represents a fundamental departure from non-relativistic quantum mechanics.

**Entanglement transformation** under Lorentz boosts (Alsing-Milburn, 2002; Jordan et al., 2007) shows γ can create maximal entanglement from finite transformations. The mathematical framework demonstrates von Neumann entropy S(ρ), mutual information I(A:B), and entanglement measures like concurrence all exhibit explicit γ-dependence.

The **information causality principle** (Pawłowski et al., Nature 2009) establishes that accessible information cannot exceed transmitted information, with relativistic light-cone structure enforcing fundamental limits. The Lorentz factor appears in constraints governing information transfer between spacelike-separated regions, preserving causal ordering through time dilation effects.

**Martin-Martinez's framework** (2011) shows relativistic quantum information requires quantum field theory formulation. Unruh-DeWitt detectors demonstrate γ-dependent information extraction from quantum fields, with entanglement harvesting protocols explicitly depending on detector acceleration through the Lorentz factor.

## Synthesis and implications

These established frameworks reveal deep connections between information theory and spacetime structure. The 511 keV scale emerges as a fundamental boundary where electromagnetic self-energy calculations require quantum corrections, potentially marking transitions between classical and quantum regimes. The Lorentz factor controls information flow and accessibility, making information itself observer-dependent in relativistic contexts.

For spacetime emergence theories, these results suggest: (1) Gravitational dynamics emerge from thermodynamic/information-theoretic principles applied to causal horizons; (2) The 511 keV scale represents electromagnetic confinement limits relevant to particle mass generation; (3) Relativistic effects fundamentally alter information processing, with γ controlling the degree of information isolation between reference frames; (4) Holographic principles demonstrate spacetime geometry encodes quantum information structure.

These peer-reviewed foundations provide solid grounding for mathematical relationships in spacetime emergence theories, though significant theoretical development remains needed to fully connect the 511 keV scale to quantum-classical transitions in atomic systems.